@@ -10,7 +10,7 @@ __all__ = [
 ]
 
 from itertools import chain
-from typing import Any, ClassVar, Dict, Generic, Iterable, Iterator, List, Optional, Set, Tuple, TypeVar, Union
+from typing import Any, ClassVar, Dict, Generic, Iterable, List, Optional, Set, Tuple, TypeVar, Union
 
 import attr
 
@@ -31,7 +31,6 @@ class AnyProperty(Property):
 
     _type_string: ClassVar[str] = "Any"
     _json_type_string: ClassVar[str] = "Any"
-    template: ClassVar[Optional[str]] = "any_property.py.jinja"
 
 
 @attr.s(auto_attribs=True, frozen=True)
@@ -50,6 +49,12 @@ class StringProperty(Property):
     pattern: Optional[str] = None
     _type_string: ClassVar[str] = "str"
     _json_type_string: ClassVar[str] = "str"
+    _allowed_locations: ClassVar[Set[oai.ParameterLocation]] = {
+        oai.ParameterLocation.QUERY,
+        oai.ParameterLocation.PATH,
+        oai.ParameterLocation.COOKIE,
+        oai.ParameterLocation.HEADER,
+    }
 
 
 @attr.s(auto_attribs=True, frozen=True)
@@ -124,6 +129,13 @@ class FloatProperty(Property):
 
     _type_string: ClassVar[str] = "float"
     _json_type_string: ClassVar[str] = "float"
+    _allowed_locations: ClassVar[Set[oai.ParameterLocation]] = {
+        oai.ParameterLocation.QUERY,
+        oai.ParameterLocation.PATH,
+        oai.ParameterLocation.COOKIE,
+        oai.ParameterLocation.HEADER,
+    }
+    template: ClassVar[str] = "float_property.py.jinja"
 
 
 @attr.s(auto_attribs=True, frozen=True)
@@ -132,6 +144,13 @@ class IntProperty(Property):
 
     _type_string: ClassVar[str] = "int"
     _json_type_string: ClassVar[str] = "int"
+    _allowed_locations: ClassVar[Set[oai.ParameterLocation]] = {
+        oai.ParameterLocation.QUERY,
+        oai.ParameterLocation.PATH,
+        oai.ParameterLocation.COOKIE,
+        oai.ParameterLocation.HEADER,
+    }
+    template: ClassVar[str] = "int_property.py.jinja"
 
 
 @attr.s(auto_attribs=True, frozen=True)
@@ -140,6 +159,13 @@ class BooleanProperty(Property):
 
     _type_string: ClassVar[str] = "bool"
     _json_type_string: ClassVar[str] = "bool"
+    _allowed_locations: ClassVar[Set[oai.ParameterLocation]] = {
+        oai.ParameterLocation.QUERY,
+        oai.ParameterLocation.PATH,
+        oai.ParameterLocation.COOKIE,
+        oai.ParameterLocation.HEADER,
+    }
+    template: ClassVar[str] = "boolean_property.py.jinja"
 
 
 InnerProp = TypeVar("InnerProp", bound=Property)
@@ -182,12 +208,6 @@ class UnionProperty(Property):
 
     inner_properties: List[Property]
     template: ClassVar[str] = "union_property.py.jinja"
-    has_properties_without_templates: bool = attr.ib(init=False)
-
-    def __attrs_post_init__(self) -> None:
-        object.__setattr__(
-            self, "has_properties_without_templates", any(prop.template is None for prop in self.inner_properties)
-        )
 
     def _get_inner_type_strings(self, json: bool = False) -> Set[str]:
         return {p.get_type_string(no_optional=True, json=json) for p in self.inner_properties}
@@ -249,14 +269,6 @@ class UnionProperty(Property):
         imports.add("from typing import cast, Union")
         return imports
 
-    def inner_properties_with_template(self) -> Iterator[Property]:
-        """
-        Get all the properties that make up this `Union`.
-
-        Called by the union property macros to aid in construction / deserialization.
-        """
-        return (prop for prop in self.inner_properties if prop.template)
-
 
 def _string_based_property(
     name: str, required: bool, data: oai.Schema, config: Config
@@ -441,6 +453,7 @@ def build_union_property(
             constructed `UnionProperty` or a `PropertyError` describing what went wrong.
     """
     sub_properties: List[Property] = []
+
     for i, sub_prop_data in enumerate(chain(data.anyOf, data.oneOf)):
         sub_prop, schemas = property_from_data(
             name=f"{name}_type_{i}",
@@ -558,8 +571,8 @@ def _property_from_data(
     if isinstance(data, oai.Reference):
         return _property_from_ref(name=name, required=required, parent=None, data=data, schemas=schemas, config=config)
 
+    sub_data: List[Union[oai.Schema, oai.Reference]] = data.allOf + data.anyOf + data.oneOf
     # A union of a single reference should just be passed through to that reference (don't create copy class)
-    sub_data = (data.allOf or []) + data.anyOf + data.oneOf
     if len(sub_data) == 1 and isinstance(sub_data[0], oai.Reference):
         return _property_from_ref(
             name=name, required=required, parent=data, data=sub_data[0], schemas=schemas, config=config
